# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.brand import Brand

class TestBrand(unittest.TestCase):
    """Brand unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Brand:
        """Test Brand
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Brand`
        """
        model = Brand()
        if include_optional:
            return Brand(
                brand_uuid = '',
                domain = '',
                default = True,
                branding_title = '',
                branding_logo = '',
                branding_favicon = '',
                flow_authentication = '',
                flow_invalidation = '',
                flow_recovery = '',
                flow_unenrollment = '',
                flow_user_settings = '',
                flow_device_code = '',
                default_application = '',
                web_certificate = '',
                attributes = None
            )
        else:
            return Brand(
                brand_uuid = '',
                domain = '',
        )
        """

    def testBrand(self):
        """Test Brand"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
