# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class DigestAlgorithmEnum(str, Enum):
    """
    DigestAlgorithmEnum
    """

    """
    allowed enum values
    """
    HTTP_COLON_SLASH_SLASH_WWW_DOT_W3_DOT_ORG_SLASH_2000_SLASH_09_SLASH_XMLDSIG_HASH_SHA1 = 'http://www.w3.org/2000/09/xmldsig#sha1'
    HTTP_COLON_SLASH_SLASH_WWW_DOT_W3_DOT_ORG_SLASH_2001_SLASH_04_SLASH_XMLENC_HASH_SHA256 = 'http://www.w3.org/2001/04/xmlenc#sha256'
    HTTP_COLON_SLASH_SLASH_WWW_DOT_W3_DOT_ORG_SLASH_2001_SLASH_04_SLASH_XMLDSIG_MINUS_MORE_HASH_SHA384 = 'http://www.w3.org/2001/04/xmldsig-more#sha384'
    HTTP_COLON_SLASH_SLASH_WWW_DOT_W3_DOT_ORG_SLASH_2001_SLASH_04_SLASH_XMLENC_HASH_SHA512 = 'http://www.w3.org/2001/04/xmlenc#sha512'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of DigestAlgorithmEnum from a JSON string"""
        return cls(json.loads(json_str))


