# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class PromptTypeEnum(str, Enum):
    """
    PromptTypeEnum
    """

    """
    allowed enum values
    """
    TEXT = 'text'
    TEXT_AREA = 'text_area'
    TEXT_READ_ONLY = 'text_read_only'
    TEXT_AREA_READ_ONLY = 'text_area_read_only'
    USERNAME = 'username'
    EMAIL = 'email'
    PASSWORD = 'password'
    NUMBER = 'number'
    CHECKBOX = 'checkbox'
    RADIO_MINUS_BUTTON_MINUS_GROUP = 'radio-button-group'
    DROPDOWN = 'dropdown'
    DATE = 'date'
    DATE_MINUS_TIME = 'date-time'
    FILE = 'file'
    SEPARATOR = 'separator'
    HIDDEN = 'hidden'
    STATIC = 'static'
    AK_MINUS_LOCALE = 'ak-locale'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of PromptTypeEnum from a JSON string"""
        return cls(json.loads(json_str))


