# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.endpoint import Endpoint

class TestEndpoint(unittest.TestCase):
    """Endpoint unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Endpoint:
        """Test Endpoint
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Endpoint`
        """
        model = Endpoint()
        if include_optional:
            return Endpoint(
                pk = '',
                name = '',
                provider = 56,
                provider_obj = authentik_client.models.rac_provider.RACProvider(
                    pk = 56, 
                    name = '', 
                    authentication_flow = '', 
                    authorization_flow = '', 
                    property_mappings = [
                        ''
                        ], 
                    component = '', 
                    assigned_application_slug = '', 
                    assigned_application_name = '', 
                    assigned_backchannel_application_slug = '', 
                    assigned_backchannel_application_name = '', 
                    verbose_name = '', 
                    verbose_name_plural = '', 
                    meta_model_name = '', 
                    settings = null, 
                    outpost_set = [
                        ''
                        ], 
                    connection_expiry = '', 
                    delete_token_on_disconnect = True, ),
                protocol = 'rdp',
                host = '',
                settings = None,
                property_mappings = [
                    ''
                    ],
                auth_mode = 'static',
                launch_url = '',
                maximum_connections = -2147483648
            )
        else:
            return Endpoint(
                pk = '',
                name = '',
                provider = 56,
                provider_obj = authentik_client.models.rac_provider.RACProvider(
                    pk = 56, 
                    name = '', 
                    authentication_flow = '', 
                    authorization_flow = '', 
                    property_mappings = [
                        ''
                        ], 
                    component = '', 
                    assigned_application_slug = '', 
                    assigned_application_name = '', 
                    assigned_backchannel_application_slug = '', 
                    assigned_backchannel_application_name = '', 
                    verbose_name = '', 
                    verbose_name_plural = '', 
                    meta_model_name = '', 
                    settings = null, 
                    outpost_set = [
                        ''
                        ], 
                    connection_expiry = '', 
                    delete_token_on_disconnect = True, ),
                protocol = 'rdp',
                host = '',
                auth_mode = 'static',
                launch_url = '',
        )
        """

    def testEndpoint(self):
        """Test Endpoint"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
