# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.notification_transport_request import NotificationTransportRequest

class TestNotificationTransportRequest(unittest.TestCase):
    """NotificationTransportRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NotificationTransportRequest:
        """Test NotificationTransportRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NotificationTransportRequest`
        """
        model = NotificationTransportRequest()
        if include_optional:
            return NotificationTransportRequest(
                name = '0',
                mode = 'local',
                webhook_url = '',
                webhook_mapping = '',
                send_once = True
            )
        else:
            return NotificationTransportRequest(
                name = '0',
        )
        """

    def testNotificationTransportRequest(self):
        """Test NotificationTransportRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
