# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.rac_api import RacApi


class TestRacApi(unittest.TestCase):
    """RacApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RacApi()

    def tearDown(self) -> None:
        pass

    def test_rac_connection_tokens_destroy(self) -> None:
        """Test case for rac_connection_tokens_destroy

        """
        pass

    def test_rac_connection_tokens_list(self) -> None:
        """Test case for rac_connection_tokens_list

        """
        pass

    def test_rac_connection_tokens_partial_update(self) -> None:
        """Test case for rac_connection_tokens_partial_update

        """
        pass

    def test_rac_connection_tokens_retrieve(self) -> None:
        """Test case for rac_connection_tokens_retrieve

        """
        pass

    def test_rac_connection_tokens_update(self) -> None:
        """Test case for rac_connection_tokens_update

        """
        pass

    def test_rac_connection_tokens_used_by_list(self) -> None:
        """Test case for rac_connection_tokens_used_by_list

        """
        pass

    def test_rac_endpoints_create(self) -> None:
        """Test case for rac_endpoints_create

        """
        pass

    def test_rac_endpoints_destroy(self) -> None:
        """Test case for rac_endpoints_destroy

        """
        pass

    def test_rac_endpoints_list(self) -> None:
        """Test case for rac_endpoints_list

        """
        pass

    def test_rac_endpoints_partial_update(self) -> None:
        """Test case for rac_endpoints_partial_update

        """
        pass

    def test_rac_endpoints_retrieve(self) -> None:
        """Test case for rac_endpoints_retrieve

        """
        pass

    def test_rac_endpoints_update(self) -> None:
        """Test case for rac_endpoints_update

        """
        pass

    def test_rac_endpoints_used_by_list(self) -> None:
        """Test case for rac_endpoints_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
