# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.oauth2_api import Oauth2Api


class TestOauth2Api(unittest.TestCase):
    """Oauth2Api unit test stubs"""

    def setUp(self) -> None:
        self.api = Oauth2Api()

    def tearDown(self) -> None:
        pass

    def test_oauth2_access_tokens_destroy(self) -> None:
        """Test case for oauth2_access_tokens_destroy

        """
        pass

    def test_oauth2_access_tokens_list(self) -> None:
        """Test case for oauth2_access_tokens_list

        """
        pass

    def test_oauth2_access_tokens_retrieve(self) -> None:
        """Test case for oauth2_access_tokens_retrieve

        """
        pass

    def test_oauth2_access_tokens_used_by_list(self) -> None:
        """Test case for oauth2_access_tokens_used_by_list

        """
        pass

    def test_oauth2_authorization_codes_destroy(self) -> None:
        """Test case for oauth2_authorization_codes_destroy

        """
        pass

    def test_oauth2_authorization_codes_list(self) -> None:
        """Test case for oauth2_authorization_codes_list

        """
        pass

    def test_oauth2_authorization_codes_retrieve(self) -> None:
        """Test case for oauth2_authorization_codes_retrieve

        """
        pass

    def test_oauth2_authorization_codes_used_by_list(self) -> None:
        """Test case for oauth2_authorization_codes_used_by_list

        """
        pass

    def test_oauth2_refresh_tokens_destroy(self) -> None:
        """Test case for oauth2_refresh_tokens_destroy

        """
        pass

    def test_oauth2_refresh_tokens_list(self) -> None:
        """Test case for oauth2_refresh_tokens_list

        """
        pass

    def test_oauth2_refresh_tokens_retrieve(self) -> None:
        """Test case for oauth2_refresh_tokens_retrieve

        """
        pass

    def test_oauth2_refresh_tokens_used_by_list(self) -> None:
        """Test case for oauth2_refresh_tokens_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
