# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.radius_check_access import RadiusCheckAccess

class TestRadiusCheckAccess(unittest.TestCase):
    """RadiusCheckAccess unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RadiusCheckAccess:
        """Test RadiusCheckAccess
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RadiusCheckAccess`
        """
        model = RadiusCheckAccess()
        if include_optional:
            return RadiusCheckAccess(
                attributes = '',
                access = authentik_client.models.policy_test_result.PolicyTestResult(
                    passing = True, 
                    messages = [
                        ''
                        ], 
                    log_messages = [
                        authentik_client.models.log_event.LogEvent(
                            timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            log_level = 'critical', 
                            logger = '', 
                            event = '', 
                            attributes = {
                                'key' : null
                                }, )
                        ], )
            )
        else:
            return RadiusCheckAccess(
                access = authentik_client.models.policy_test_result.PolicyTestResult(
                    passing = True, 
                    messages = [
                        ''
                        ], 
                    log_messages = [
                        authentik_client.models.log_event.LogEvent(
                            timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            log_level = 'critical', 
                            logger = '', 
                            event = '', 
                            attributes = {
                                'key' : null
                                }, )
                        ], ),
        )
        """

    def testRadiusCheckAccess(self):
        """Test RadiusCheckAccess"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
