# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.authenticator_static_stage_request import AuthenticatorStaticStageRequest

class TestAuthenticatorStaticStageRequest(unittest.TestCase):
    """AuthenticatorStaticStageRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AuthenticatorStaticStageRequest:
        """Test AuthenticatorStaticStageRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuthenticatorStaticStageRequest`
        """
        model = AuthenticatorStaticStageRequest()
        if include_optional:
            return AuthenticatorStaticStageRequest(
                name = '0',
                flow_set = [
                    authentik_client.models.flow_set_request.FlowSetRequest(
                        name = '0', 
                        slug = 'z0', 
                        title = '0', 
                        designation = null, 
                        policy_engine_mode = 'all', 
                        compatibility_mode = True, 
                        layout = 'stacked', 
                        denied_action = null, )
                    ],
                configure_flow = '',
                friendly_name = '0',
                token_count = 0,
                token_length = 0
            )
        else:
            return AuthenticatorStaticStageRequest(
                name = '0',
        )
        """

    def testAuthenticatorStaticStageRequest(self):
        """Test AuthenticatorStaticStageRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
